==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Dashboard.pm <==
package WebGUI::i18n::German::Asset_Dashboard;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1164282567',
    'message' => 'Dashboard'
  },
  'assets to hide' => {
    'lastUpdated' => '1180078541',
    'message' => 'Assets zum Verbergen'
  },
  'assets to hide description' => {
    'lastUpdated' => '1180078717',
    'message' => 'Diese Liste entält ein Auswahlfeld für jedes Asset auf der Seite. W&auml;hlen Sie hier die Assets aus, die nicht auf der Seite dargestellt werden sollen.'
  },
  'dashboard adminsGroupId description' => {
    'lastUpdated' => '1180079188',
    'message' => 'Welche Gruppe kann dieses Dashboard administrieren. Hinzufügen/Bearbeiten/Entfernen verf&uuml;gbarer Dashlets, Präferenzen und Templates.'
  },
  'dashboard adminsGroupId field label' => {
    'lastUpdated' => '1180079197',
    'message' => 'Wer darf verwalten?'
  },
  'dashboard template description' => {
    'lastUpdated' => '1180079232',
    'message' => 'Wählen Sie ein Dashboard/Portal Template. Standard ist das <strong>Three Column Layout</strong>'
  },
  'dashboard template field label' => {
    'lastUpdated' => '1180079239',
    'message' => 'Dashboard Template'
  },
  'dashboard usersGroupId description' => {
    'lastUpdated' => '1180079494',
    'message' => 'Gruppe, deren Mitglieder ihre eigenen Personalisierungen/Präferenzen speicher können. Falls ein Benutzer in der "Wer kann das Asset sehen?" Grupe ist, darf dieser die Anordnung von Dashlets personalisieren (Positionen werden in Cookies gespeichert), sie dürfen aber die Eigenschaften der einzelnen Dashlets nicht &auml;ndern.'
  },
  'dashboard usersGroupId field label' => {
    'lastUpdated' => '1180079505',
    'message' => 'Wer darf personalisieren?'
  },
  'hide new content list' => {
    'lastUpdated' => '1234738453',
    'message' => '"Neuer Inhalt" verbergen'
  }
}
;

1;

==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Dashboard.pm <==
package WebGUI::i18n::German::Asset_Dashboard;
use utf8;
our $I18N = {
  'Add New Content' => {
    'lastUpdated' => '1301989131',
    'message' => 'Neue Inhalte hinzufügen'
  },
  'Dashboard Template Variables' => {
    'lastUpdated' => '1301989146',
    'message' => 'Dashboard Template-Variablen'
  },
  'Edit Dashlet' => {
    'lastUpdated' => '1301989157',
    'message' => 'Dashlet bearbeiten'
  },
  'Is required' => {
    'lastUpdated' => '1303289901',
    'message' => 'Pflicht-Dashlet'
  },
  'Is required help' => {
    'lastUpdated' => '1303289892',
    'message' => 'Darf dieses Dashlet vom Nutzer des Dashboards gelöscht werden?'
  },
  'Is static' => {
    'lastUpdated' => '1303289947',
    'message' => 'Statisches Dashlet'
  },
  'Is static help' => {
    'lastUpdated' => '1303289934',
    'message' => 'Darf dieses Dashlet vom Nutzer des Dashboards verschoben werden?'
  },
  'adminsGroupId' => {
    'lastUpdated' => '1303290002',
    'message' => 'Die GUID der Gruppe, die die Standardansicht des Dashboards für Besucher festlegen darf.'
  },
  'assetName' => {
    'lastUpdated' => '1164282567',
    'message' => 'Dashboard'
  },
  'assets to hide' => {
    'lastUpdated' => '1180078541',
    'message' => 'Assets zum Verbergen'
  },
  'assets to hide description' => {
    'lastUpdated' => '1180078717',
    'message' => 'Diese Liste entält ein Auswahlfeld für jedes Asset auf der Seite. W&auml;hlen Sie hier die Assets aus, die nicht auf der Seite dargestellt werden sollen.'
  },
  'content' => {
    'lastUpdated' => '1301989188',
    'message' => 'Dashlet-Inhalt'
  },
  'dashboard adminsGroupId description' => {
    'lastUpdated' => '1180079188',
    'message' => 'Welche Gruppe kann dieses Dashboard administrieren. Hinzufügen/Bearbeiten/Entfernen verf&uuml;gbarer Dashlets, Präferenzen und Templates.'
  },
  'dashboard adminsGroupId field label' => {
    'lastUpdated' => '1180079197',
    'message' => 'Wer darf verwalten?'
  },
  'dashboard template description' => {
    'lastUpdated' => '1180079232',
    'message' => 'Wählen Sie ein Dashboard/Portal Template. Standard ist das <strong>Three Column Layout</strong>'
  },
  'dashboard template field label' => {
    'lastUpdated' => '1180079239',
    'message' => 'Dashboard Template'
  },
  'dashboard usersGroupId description' => {
    'lastUpdated' => '1180079494',
    'message' => 'Gruppe, deren Mitglieder ihre eigenen Personalisierungen/Präferenzen speicher können. Falls ein Benutzer in der "Wer kann das Asset sehen?" Grupe ist, darf dieser die Anordnung von Dashlets personalisieren (Positionen werden in Cookies gespeichert), sie dürfen aber die Eigenschaften der einzelnen Dashlets nicht &auml;ndern.'
  },
  'dashboard usersGroupId field label' => {
    'lastUpdated' => '1180079505',
    'message' => 'Wer darf personalisieren?'
  },
  'hide new content list' => {
    'lastUpdated' => '1234738453',
    'message' => '"Neuer Inhalt" verbergen'
  },
  'id' => {
    'lastUpdated' => '1303290025',
    'message' => 'Asset-ID des aktuellen Dashlets'
  }
}
;

1;
